import threading
import time
import pycessingame

size(500,500)

def worker():
    print("Worker startet")
    run()
    print("run fertig")

t = threading.Thread(target=worker)  # Nicht-Daemon by default
t.start()

print("Main beendet")  # Das Programm wartet automatisch, bis t fertig ist